==> kubernetes-client_3-0.11.0-sources.jar: ConfigMapProjection.scala <==
package io.k8s.api.core.v1

import io.circe.*
import io.circe.generic.semiauto.*

/** Adapts a ConfigMap into a projected volume.

The contents of the target ConfigMap's Data field will be presented in a projected volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. Note that this is identical to a configmap volume source without the default mode.
 *
 *  @param    items  items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected
 *                   into the volume as a file whose name is the key and content is the value. If specified, the listed keys
 *                   will be projected into the specified paths, and unlisted keys will not be present. If a key is specified
 *                   which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths
 *                   must be relative and may not contain the '..' path or start with '..'.
 *  @param     name  Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
 *  @param optional  optional specify whether the ConfigMap or its keys must be defined
*/
case class ConfigMapProjection(
  items: Option[Seq[io.k8s.api.core.v1.KeyToPath]] = None,
  name: Option[String] = None,
  optional: Option[Boolean] = None
)

object ConfigMapProjection {
  implicit lazy val encoder: Encoder.AsObject[ConfigMapProjection] = deriveEncoder
  implicit lazy val decoder: Decoder[ConfigMapProjection] = deriveDecoder
}

==> kubernetes-client_3-0.11.1-sources.jar: ConfigMapProjection.scala <==
package io.k8s.api.core.v1

import io.circe.*
import io.circe.generic.semiauto.*

/** Adapts a ConfigMap into a projected volume.

The contents of the target ConfigMap's Data field will be presented in a projected volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. Note that this is identical to a configmap volume source without the default mode.
 *
 *  @param    items  items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected
 *                   into the volume as a file whose name is the key and content is the value. If specified, the listed keys
 *                   will be projected into the specified paths, and unlisted keys will not be present. If a key is specified
 *                   which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths
 *                   must be relative and may not contain the '..' path or start with '..'.
 *  @param     name  Name of the referent. This field is effectively required, but due to backwards compatibility is allowed
 *                   to be empty. Instances of this type with an empty value here are almost certainly wrong. More info:
 *                   https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
 *  @param optional  optional specify whether the ConfigMap or its keys must be defined
*/
case class ConfigMapProjection(
  items: Option[Seq[io.k8s.api.core.v1.KeyToPath]] = None,
  name: Option[String] = None,
  optional: Option[Boolean] = None
)

object ConfigMapProjection {
  implicit lazy val encoder: Encoder.AsObject[ConfigMapProjection] = deriveEncoder
  implicit lazy val decoder: Decoder[ConfigMapProjection] = deriveDecoder
}
